@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.16 2000/04/14 11:18:50 fredgo Exp $
+# $Id: Editor.py,v 1.17 2000/04/18 08:46:29 fredgo Exp $
 
 import string, re
 from gnome.ui import *
@@ -227,7 +227,16 @@ class AuthorGroup (BaseField):
             author = string.strip (author)
             if author == '': continue
 
-            group.append (Fields.Author (author))
+            fields = string.split (author, ',')
+
+            if   len (fields) == 1:
+                (first, last, lineage) = (None, fields [0], None)
+            elif len (fields) == 2:
+                (first, last, lineage) = (fields [1], fields [0], None)
+            else:
+                (first, last, lineage) = (fields [2], fields [0], fields [1])
+                
+            group.append (Fields.Author ((None, first, last, lineage)))
         
         entry [self.field] = group
         return
