@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtexmodule.c,v 1.3 2000/02/23 10:25:13 fredgo Exp $
+ $Id: bibtexmodule.c,v 1.5 2000/04/14 11:18:00 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -474,7 +474,7 @@ bib_next (PyObject * self, PyObject * args)
     BibtexSource * file;
     PyBibtexSource_Object * file_obj;
 
-    PyObject * dico, * tmp, * tmp2;
+    PyObject * dico, * tmp, * tmp2, * name;
 
     if (! PyArg_ParseTuple(args, "O!:next", & PyBibtexSource_Type, & file_obj))
 	return NULL;
@@ -495,7 +495,14 @@ bib_next (PyObject * self, PyObject * args)
     dico = PyDict_New (); 
     g_hash_table_foreach (ent->table, fill_dico, dico);
 
-    tmp = Py_BuildValue ("ssiiO", ent->name, ent->type, 
+    if (ent->name) {
+      name = PyString_FromString (ent->name);
+    }
+    else {
+      name = Py_None;
+    }
+
+    tmp = Py_BuildValue ("OsiiO", name, ent->type, 
 			 ent->offset, ent->start_line,
 			 dico);
     Py_DECREF (dico);
@@ -551,9 +558,9 @@ bib_reverse (PyObject * self, PyObject * args)
     BibtexFieldType type;
     BibtexAuthor * auth;
 
-    gint length, i;
+    gint length, i, brace;
 
-    if (! PyArg_ParseTuple(args, "iO:reverse", & type, & tuple))
+    if (! PyArg_ParseTuple(args, "iiO:reverse", & type, & brace, & tuple))
 	return NULL;
 
     field = bibtex_field_new (type);
@@ -641,7 +648,7 @@ bib_reverse (PyObject * self, PyObject * args)
 	}
     }
 
-    bibtex_reverse_field (field);
+    bibtex_reverse_field (field, brace);
 
     tmp = (PyObject *) PyObject_NEW (PyBibtexField_Object, & PyBibtexField_Type);
     ((PyBibtexField_Object *) tmp)->obj = field;
